==> jc-1.4.0.tar.gz: soot/baf/GroupIntPair.h <==
// class soot.baf.GroupIntPair

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9ac0366a3f0b8422 soot_baf_GroupIntPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_baf_GroupIntPair_H_
#define _JC_soot_baf_GroupIntPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_baf_GroupIntPair$sub_refs	_jc_soot_baf_GroupIntPair$sub_refs;
typedef struct _jc_soot_baf_GroupIntPair$sub_nonrefs	_jc_soot_baf_GroupIntPair$sub_nonrefs;
typedef struct _jc_soot_baf_GroupIntPair$refs	_jc_soot_baf_GroupIntPair$refs;
typedef struct _jc_soot_baf_GroupIntPair$nonrefs	_jc_soot_baf_GroupIntPair$nonrefs;
typedef struct _jc_soot_baf_GroupIntPair$object	_jc_soot_baf_GroupIntPair$object;

typedef const struct _jc_soot_baf_GroupIntPair$vmethods	_jc_soot_baf_GroupIntPair$vmethods;
typedef const struct _jc_soot_baf_GroupIntPair$vtable	_jc_soot_baf_GroupIntPair$vtable;
typedef const struct _jc_soot_baf_GroupIntPair$vtype	_jc_soot_baf_GroupIntPair$vtype;

// Constructors
extern void _jc_soot_baf_GroupIntPair$method$_init$a57db7ba48d4b8bc(_jc_env *, struct _jc_soot_baf_GroupIntPair$object *, struct _jc_java_lang_Object$object *, jint);

// Virtual methods
extern jboolean _jc_soot_baf_GroupIntPair$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_baf_GroupIntPair$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_soot_baf_GroupIntPair$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_baf_GroupIntPair$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_baf_GroupIntPair$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_baf_GroupIntPair$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_baf_GroupIntPair$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_baf_GroupIntPair$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_baf_GroupIntPair$object *);
};

// Vtable
struct _jc_soot_baf_GroupIntPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_baf_GroupIntPair$vmethods	soot_baf_GroupIntPair;
};

// Vtype
struct _jc_soot_baf_GroupIntPair$vtype {
	_jc_type			type;
	_jc_soot_baf_GroupIntPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_GroupIntPair$sub_refs {
	struct _jc_java_lang_Object$object	*group;
};

// Reference instance fields (object)
struct _jc_soot_baf_GroupIntPair$refs {
    _jc_soot_baf_GroupIntPair$sub_refs	soot_baf_GroupIntPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_GroupIntPair$sub_nonrefs {
	jint	x;
};

// Non-reference instance fields (object)
struct _jc_soot_baf_GroupIntPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_baf_GroupIntPair$sub_nonrefs	soot_baf_GroupIntPair;
};

// Object instance structure
struct _jc_soot_baf_GroupIntPair$object {
	_jc_soot_baf_GroupIntPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_GroupIntPair$vtype	*vtype;
	_jc_soot_baf_GroupIntPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_GroupIntPair$vtype _jc_soot_baf_GroupIntPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_GroupIntPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_GroupIntPair$class_object;

#endif	/* _JC_soot_baf_GroupIntPair_H_ */

==> jc-1.4.6.tar.gz: soot/baf/GroupIntPair.h <==
// class soot.baf.GroupIntPair

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9ac0366a3f0b8422 soot_baf_GroupIntPair

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_baf_GroupIntPair_H_
#define _JC_soot_baf_GroupIntPair_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_soot_baf_GroupIntPair$sub_refs	_jc_soot_baf_GroupIntPair$sub_refs;
typedef struct _jc_soot_baf_GroupIntPair$sub_nonrefs	_jc_soot_baf_GroupIntPair$sub_nonrefs;
typedef struct _jc_soot_baf_GroupIntPair$refs	_jc_soot_baf_GroupIntPair$refs;
typedef struct _jc_soot_baf_GroupIntPair$nonrefs	_jc_soot_baf_GroupIntPair$nonrefs;
typedef struct _jc_soot_baf_GroupIntPair$object	_jc_soot_baf_GroupIntPair$object;

typedef const struct _jc_soot_baf_GroupIntPair$vmethods	_jc_soot_baf_GroupIntPair$vmethods;
typedef const struct _jc_soot_baf_GroupIntPair$vtable	_jc_soot_baf_GroupIntPair$vtable;
typedef const struct _jc_soot_baf_GroupIntPair$vtype	_jc_soot_baf_GroupIntPair$vtype;

// Constructors
extern void _jc_soot_baf_GroupIntPair$method$_init$a57db7ba48d4b8bc(_jc_env *, struct _jc_soot_baf_GroupIntPair$object *, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_baf_GroupIntPair$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_baf_GroupIntPair$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_baf_GroupIntPair$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_baf_GroupIntPair$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_baf_GroupIntPair$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_baf_GroupIntPair$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_soot_baf_GroupIntPair$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_baf_GroupIntPair$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_baf_GroupIntPair$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_baf_GroupIntPair$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_baf_GroupIntPair$vmethods	soot_baf_GroupIntPair;
};

// Vtype
struct _jc_soot_baf_GroupIntPair$vtype {
	_jc_type			type;
	_jc_soot_baf_GroupIntPair$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_baf_GroupIntPair$sub_refs {
	struct _jc_java_lang_Object$object	*group;
};

// Reference instance fields (object)
struct _jc_soot_baf_GroupIntPair$refs {
    _jc_soot_baf_GroupIntPair$sub_refs	soot_baf_GroupIntPair;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_baf_GroupIntPair$sub_nonrefs {
	jint	x;
};

// Non-reference instance fields (object)
struct _jc_soot_baf_GroupIntPair$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_baf_GroupIntPair$sub_nonrefs	soot_baf_GroupIntPair;
};

// Object instance structure
struct _jc_soot_baf_GroupIntPair$object {
	_jc_soot_baf_GroupIntPair$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_baf_GroupIntPair$vtype	*vtype;
	_jc_soot_baf_GroupIntPair$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_baf_GroupIntPair$vtype _jc_soot_baf_GroupIntPair$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_baf_GroupIntPair, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_baf_GroupIntPair$class_object;

#endif	/* _JC_soot_baf_GroupIntPair_H_ */
